@@ -15,7 +15,6 @@ require Exporter;
 our @ISA = qw(Exporter);
 
 
-
 sub new {
     my $class = shift @_;
     my ($job_name, $commands_array, $command, $opts);
@@ -283,7 +282,7 @@ NBI::Job - A class for representing a job for NBI::Slurm
 
 =head1 VERSION
 
-version 0.1.1
+version 0.2.0
 
 =head1 SYNOPSIS
 
@@ -300,42 +299,11 @@ Multiple commands can be encoded as a list:
     -commands => ["ls -l", "echo done"]
   );
 
-=head1 SYNOPSIS
-
-A job object supported from C<NBI::Slurm> .
-
-=over 4
-
-=item B<name>
-
-The actual sequence, the only mandatory field (string)
-
-=back
-
-  use NBI::Job;
-  my $job = new(
-    -name => "job-name",
-    -command => "ls -l",
-  );
-
-  # Multi commands
-    my $job = new(
-    -name => "job-name",
-    -commands => ["ls -l", "echo done"]
-  );
-
 =head1 DESCRIPTION
 
 The C<NBI::Job> module provides a class for representing a job to be submitted to SLURM for High-Performance Computing (HPC). 
 It allows you to define the name of the job, the commands to be executed, and various options related to the job.
 
-=head1 MAIN METHODS 
-
-=head2 new()
-
-Create a new instance of C<NBI::Seq>.
-The sequence is the only required field.
-
 =head1 METHODS
 
 =head2 new()
@@ -451,9 +419,7 @@ This method allows you to set the options for the job using an instance of the C
 
 Get the options for the job.
 
-perl
-
-my $opts = $job->get_opts;
+  my $opts = $job->get_opts;
 
 This method returns the options for the job as an instance of the CNBI::Opts class.
 
